@@ -1,7 +1,7 @@
 package Sort::Sub;
 
 our $DATE = '2015-09-27'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -44,13 +44,13 @@ Sort::Sub - Collection of sort subroutines
 
 =head1 VERSION
 
-This document describes version 0.01 of Sort::Sub (from Perl distribution Sort-Sub), released on 2015-09-27.
+This document describes version 0.02 of Sort::Sub (from Perl distribution Sort-Sub), released on 2015-09-27.
 
 =head1 SYNOPSIS
 
  use Sort::Sub qw($naturally);
 
- my @sorted = sort $naturally_parts ('track1.mp3', 'track10.mp3', 'track2.mp3', 'track1b.mp3', 'track1a.mp3');
+ my @sorted = sort $naturally ('track1.mp3', 'track10.mp3', 'track2.mp3', 'track1b.mp3', 'track1a.mp3');
  # => ('track1.mp3', 'track1a.mp3', 'track1b.mp3', 'track2.mp3', 'track10.mp3')
 
 Request as subroutine:
@@ -110,13 +110,13 @@ After the name, you can add some options, enclosed with angle brackets C<< <>
 
 =head1 GUIDELINES FOR WRITING A SORT::SUB::* MODULE
 
-The name should be in lowercase. It should be a verb (e.g. C<naturally>) or a
+The name should be in lowercase. It should be an adverb (e.g. C<naturally>) or a
 phrase with words separated by underscore (C<_>) and the phrase begins with
 C<by> (e.g. C<by_num_and_non_num_parts>).
 
 The module must contain a C<gen_sorter> subroutine. It will be called with:
 
- C<($is_reverse, $is_ci)>
+ ($is_reverse, $is_ci)
 
 Where C<$is_reserve> will be set to true if user requests a reverse sort, and
 C<$is_ci> will be set to true if user requests a case-insensitive sort. The
